const fs = require('fs');
const path = require('path');
const _ = require('lodash');
const utils = require('./utils');

/**
 * Looks for files with .html, .hbs, or .handlebars extensions within the given directory, and adds
 * them as Handlebars partials matching the name of the file.
 * @param {string} dir - Folder to check for partials.
 */
module.exports = function loadPartials(dir) {
    const partials = utils.loadFiles(dir, '**/*.{html,hbs,handlebars}');

    _.each(partials, (partial) => {
        const ext = path.extname(partial);
        const file = fs.readFileSync(partial);
        const name = path.basename(partial, ext);
        this.Handlebars.registerPartial(name, `${file.toString()}\n`);
    });
};
