import { src, dest } from 'vinyl-fs';
import equal from 'assert-dir-equal';
import { Panini } from '..';

const FIXTURES = 'test/fixtures/';

describe('Panini', () => {
    it('builds a page with a default layout', (done) => {
        const p = new Panini({
            layouts: `${FIXTURES}basic/layouts`,
        });

        p.refresh();

        src(`${FIXTURES}basic/pages/*`)
            .pipe(p.render())
            .pipe(dest(`${FIXTURES}basic/build`))
            .on('finish', () => {
                equal(`${FIXTURES}basic/expected`, `${FIXTURES}basic/build`);
                done();
            });
    });

    it('builds a page with a custom layout', (done) => {
        const p = new Panini({
            layouts: `${FIXTURES}layouts/layouts/`,
        });

        p.refresh();

        src(`${FIXTURES}layouts/pages/*`)
            .pipe(p.render())
            .pipe(dest(`${FIXTURES}layouts/build`))
            .on('finish', () => {
                equal(`${FIXTURES}layouts/expected`, `${FIXTURES}layouts/build`);
                done();
            });
    });

    it('builds a page with custom partials', (done) => {
        const p = new Panini({
            layouts: `${FIXTURES}partials/layouts/`,
            partials: `${FIXTURES}partials/partials/`,
        });

        p.refresh();

        src(`${FIXTURES}partials/pages/*`)
            .pipe(p.render())
            .pipe(dest(`${FIXTURES}partials/build`))
            .on('finish', () => {
                equal(`${FIXTURES}partials/expected`, `${FIXTURES}partials/build`);
                done();
            });
    });

    it('builds a page with custom data', (done) => {
        const p = new Panini({
            layouts: `${FIXTURES}data-page/layouts/`,
            partials: `${FIXTURES}data-page/partials/`,
        });

        p.refresh();

        src(`${FIXTURES}data-page/pages/*`)
            .pipe(p.render())
            .pipe(dest(`${FIXTURES}data-page/build`))
            .on('finish', () => {
                equal(`${FIXTURES}data-page/expected`, `${FIXTURES}data-page/build`);
                done();
            });
    });
});

describe('Panini variables', () => {
    it('{{ page }} variable that stores the current page', (done) => {
        const p = new Panini({
            layouts: `${FIXTURES}variable-page/layouts/`,
        });

        p.refresh();

        src(`${FIXTURES}variable-page/pages/*`)
            .pipe(p.render())
            .pipe(dest(`${FIXTURES}variable-page/build`))
            .on('finish', () => {
                equal(`${FIXTURES}variable-page/expected`, `${FIXTURES}variable-page/build`);
                done();
            });
    });

    it('{{layout}} variable that stores the current layout', (done) => {
        const p = new Panini({
            layouts: `${FIXTURES}variable-layout/layouts/`,
        });

        p.refresh();

        src(`${FIXTURES}variable-layout/pages/*`)
            .pipe(p.render())
            .pipe(dest(`${FIXTURES}variable-layout/build`))
            .on('finish', () => {
                equal(`${FIXTURES}variable-layout/expected`, `${FIXTURES}variable-layout/build`);
                done();
            });
    });
});
